pub enum FlexPathVariant {
Common,
Windows,
}Expand description
Indicates if special absolute paths are considered.
Currently, only two variants are defined, considering that there is no known operating system with different path support other than Windows:
CommonWindows
Variants
Common
Indicates that the path is manipulated in a Unix common way, resulting into forward slashes.
Windows
Indicates that the path is manipulated compatibly with the Windows operating system.
Implementations